"""
PROCESS_NAME  :  WINDOW_MANAGER_NAME
"""

window_manager_definitions = {
    '2wm': '2wm',
    '9wm': '9wm',
    'afterstep': 'AfterStep',
    'antiwm': 'AntiWM',
    'awesome': 'Awesome',
    'barewm': 'Bare WM',
    'beryl': 'Beryl',
    'blackbox': 'Blackbox',
    'clfswm': 'CLFS WM',
    "cinnamon": 'Cinnamon',
    'compiz': 'Compiz',
    'ctwm': 'CTWM',
    'cwm': 'CWM',
    'dswm': 'DSWM',
    'dwm': 'DWM',
    'echinus': 'Echinus',
    'enlightenment': 'Enlightenment',
    'euclid': 'Euclid',
    'evil-wm': 'EvilWM',
    'evilpoison': 'EviL Poison',
    'fluxbox': 'Fluxbox',
    'flwm': 'FLWM',
    'fvwm': 'FVWM',
    'hackedbox': 'Hackedbox',
    'hildon-desktop': 'Matchbox',
    'i3': 'i3',
    'icewm': 'IceWM',
    'ion-3': 'Ion3',
    'ion3': 'Ion3',
    'jwm': 'JWM',
    'karmen': 'Karmen',
    'kwin': 'Kwin',
    'kodi-standalone': 'Kodi',
    'larswm': 'Lars WM',
    'lewm': 'LEWM',
    'lwm': 'LWM',
    'matwm2': 'matWM2',
    'metacity': 'Metacity',
    'musca': 'Musca',
    'notion': 'Notion',
    'openbox': 'Openbox',
    'openbox-gnome-session': 'Openbox (GNOME session)',
    'openbox-kde-session': 'Openbox (KDE session)',
    'pawm': 'PAWM',
    'pekwm': 'PekWM',
    'qlwm': 'qLWM',
    'qtile': 'qTile',
    'quarkwm': 'QuarkWM',
    'ratpoison': 'ratpoison',
    'sawfish': 'Sawfish',
    'scrot-wm': 'ScrotWM',
    'scrotwm': 'ScrotWM',
    'sithwm': 'SithWM',
    'stumpwm': 'StumpWM',
    'subtle': 'Subtle',
    'swm': 'SWM',
    'tinywm': 'TinyWM',
    'tritium': 'Tritium',
    'twm': 'twm',
    'velox': 'Velox',
    'vtwm': 'VtWM',
    'vwm': 'VWM',
    'w9wm': 'w9wm',
    'weewm': 'WeeWM',
    'windowmaker': 'WindowMaker',
    'windwm': 'WindWM',
    'wmaker': 'WindowMaker',
    'wmfs': 'Wmfs',
    'WMFS': 'WMFS',
    'wmii': 'wmii',
    'wmii36': 'wmii36',
    'xmonad': 'xmonad',
    'yeahwm': 'YeahWM',
}
